Crate spf

Crate spf 

Parser and serializer for the SimplePixelFont (.spf) binary font format.

This crate provides the native Rust API (see core) and, when the ffi feature is enabled, a C ABI compatible layer (see ffi) for using spf.rs from other languages. See the articles module for usage guides.

Modules

articlesarticles
Helpful guides and learning resources to integrate spf.rs in your next project.
core
Essential functions and structs used by both the native crate and FFI interface.
ffiffi
A C compatible FFI layer for spf.rs.
taggingtagging
Tools to record the exact byte:bit Span of every field written or read, tagged by TagKind, so a .spf file’s structure can be inspected after a parse or serialize pass.