#[non_exhaustive]pub struct ColorTable {
pub modifier_flags: ColorTableModifierFlags,
pub configuration_flags: ColorTableConfigurationFlags,
pub constant_alpha: Option<u8>,
pub colors: Vec<Color>,
}Expand description
Stores RGBA color values that can be referenced by pixmap data.
Use Cases
- Pixmap palettes - When linked to a Pixmap Table, provides the color palette for indexed pixel data.
- Color storage - Can store color sets independently for other purposes.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.modifier_flags: ColorTableModifierFlagsWhich optional per-color fields are present.
configuration_flags: ColorTableConfigurationFlagsWhich configuration values below are present for every color.
constant_alpha: Option<u8>If ColorTableConfigurationFlags::ConstantAlpha is enabled.
The alpha channel value applied to all colors in this table.
colors: Vec<Color>The colors stored in this table.