Modules
- articles
articles - Helpful guides and learning resources to integrate spf.rs in your next project.
- core
- Essential functions and structs used by both the native crate and FFI interface.
- ffi
ffi - A C compatible FFI layer for
spf.rs. - tagging
tagging - Tools to record the exact byte:bit
Spanof every field written or read, tagged byTagKind, so a.spffile’s structure can be inspected after a parse or serialize pass.