pub struct ColorTable {
pub constant_alpha: Option<u8>,
pub colors: Vec<Color>,
}Fields
constant_alpha: Option<u8>colors: Vec<Color>Trait Implementations
Sourceimpl Clone for ColorTable
impl Clone for ColorTable
Sourcefn clone(&self) -> ColorTable
fn clone(&self) -> ColorTable
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ColorTable
impl Debug for ColorTable
Sourceimpl Default for ColorTable
impl Default for ColorTable
Sourcefn default() -> ColorTable
fn default() -> ColorTable
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for ColorTable
impl<'de> Deserialize<'de> for ColorTable
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl From<TableBuilderResult> for ColorTable
Available on crate feature ergonomics only.
impl From<TableBuilderResult> for ColorTable
Available on crate feature
ergonomics only.Sourcefn from(table_builder_result: TableBuilderResult) -> Self
fn from(table_builder_result: TableBuilderResult) -> Self
Converts to this type from the input type.
Sourceimpl Serialize for ColorTable
impl Serialize for ColorTable
Sourceimpl TryFrom<ColorTable> for SPFColorTable
Available on crate feature ffi only.
impl TryFrom<ColorTable> for SPFColorTable
Available on crate feature
ffi only.Sourcetype Error = ConversionError
type Error = ConversionError
The type returned in the event of a conversion error.
Sourceimpl TryInto<ColorTable> for &SPFColorTable
Available on crate feature ffi only.
impl TryInto<ColorTable> for &SPFColorTable
Available on crate feature
ffi only.Sourcetype Error = ConversionError
type Error = ConversionError
The type returned in the event of a conversion error.